require "spec_helper"

describe Cubaru::V1::Address::Resource do
  let(:sample_params2) {
    {
      name:    "Test1",
      email:   "test@test.com",
      address_line1: "テスト区テスト町１−２",
      city:    "横浜市",
      state:   "神奈川",
      country: "JP",
      zip:     "2220002"
    }
  }

  let(:sample_params) {
    {
      name:    "Test",
      email:   "test@test.com",
      address_line1: "テスト町１−１",
      city:    "港区",
      state:   "東京都",
      country: "JP",
      zip:     "108-0000"
    }
  }

  subject { Cubaru(api_key: ENV["CUBARU_API_KEY"], api_version: "v1") }

  describe "list" do
    it "should list addresses" do
			VCR.use_cassette('list_addresses') do
				new_address = subject.addresses.create sample_params
				list_result = subject.addresses.list
				expect(list_result.to_s).to match(/#{new_address["name"]}/)
			end
    end
  end


  describe "create" do
    it "should create an address" do
      VCR.use_cassette('create_address') do
        result = subject.addresses.create sample_params
				expect(sample_params[:name].to_s).to match(/#{result["name"]}/)
      end
    end
  end


  describe "find" do
    it "should find an address" do
      VCR.use_cassette('find_address') do
        new_address = subject.addresses.create sample_params

        find_result = subject.addresses.find(new_address["id"])
				expect(find_result['name']).to match(/#{sample_params[:name]}/)
      end
    end
  end


  describe "destroy" do
    it "should delete an address" do
      VCR.use_cassette('delete_address') do
        new_address = subject.addresses.create sample_params
        expect { subject.addresses.destroy(new_address["id"]) }.not_to raise_error
      end
    end
  end
end
