require "spec_helper"

describe Cubaru::V1::Postcard::Resource do

  before :each do
    @sample_address_params = {
      name:    "Test1",
      email:   "test@test.com",
      address_line1: "テスト区テスト町１−２",
      address_line2: "テストハイツ201",
      city:    "横浜市",
      state:   "神奈川",
      country: "JP",
      zip:     "2220002"
    }

    @sample_postcard_params    = {
      name:    "TestPostcard",
    }
  end

  subject { Cubaru(api_key: ENV["CUBARU_API_KEY"], api_version: "v1") }

  describe "create" do
    it "should create a postcard with address_id" do
      VCR.use_cassette('create_postcard_with_address_id') do
        new_address = subject.addresses.create @sample_address_params

        result = subject.postcards.create(
          name: @sample_postcard_params[:name],
          to: new_address["id"],
					from: @sample_address_params,
          back: "https://www.cubaru.com/back.pdf"
        )

        expect(result["name"]).to eq(@sample_postcard_params[:name])
      end
    end


    it "should create a postcard with address params" do
      VCR.use_cassette('create_postcard_with_address_params') do

        result = subject.postcards.create(
          name: @sample_postcard_params[:name],
          to: @sample_address_params,
					from: @sample_address_params,
          back: "https://www.cubaru.com/back.pdf"
        )

        expect(result["name"]).to eq(@sample_postcard_params[:name])
      end
    end


    it "should create a postcard with front and back as urls" do
      VCR.use_cassette('create_postcard_with_front_and_back_urls') do
        new_address = subject.addresses.create @sample_address_params

        result = subject.postcards.create(
          name: @sample_postcard_params[:name],
          to: new_address["id"],
					from: @sample_address_params,
          front: "https://www.cubaru.com/front.pdf",
          back:  "https://www.cubaru.com/back.pdf"
        )

        expect(result["name"]).to eq(@sample_postcard_params[:name])
      end
    end

		it "should create a postcard with front and back as PDFs" do
			VCR.use_cassette('create_postcard_with_front_and_back_pdfs') do
				new_address = subject.addresses.create @sample_address_params

				result = subject.postcards.create(
					name: @sample_postcard_params[:name],
					to: new_address["id"],
					from: @sample_address_params,
          front: fixture_file('front.pdf'),
          back: fixture_file('back.pdf')
				)

				expect(result["name"]).to eq @sample_postcard_params[:name]
			end
		end

  end


  describe "find" do
    it "should find a postcard" do
      VCR.use_cassette('find_postcard') do
        new_address = subject.addresses.create @sample_address_params

        new_postcard = subject.postcards.create(
          name: @sample_postcard_params[:name],
          to: new_address["id"],
					from: @sample_address_params,
          front: fixture_file('front.pdf'),
          back: fixture_file('back.pdf')
        )

        result  = subject.postcards.find(new_postcard["id"])
        expect(result["name"]).to eq(@sample_postcard_params[:name])
      end
    end
  end

  describe "list" do
    it "should list postcards" do
      VCR.use_cassette('list_postcards') do
        new_address = subject.addresses.create @sample_address_params

        new_postcard = subject.postcards.create(
          name: @sample_postcard_params[:name],
          to: new_address["id"],
					from: @sample_address_params,
          front: fixture_file('front.pdf'),
          back: fixture_file('back.pdf')
        )

        list_result = subject.postcards.list
	      expect(list_result.to_s).to match /#{new_postcard["name"]}/
      end
    end
  end

end
